"""Generated message classes for anthosevents version v1alpha1.

"""
# NOTE: This file is autogenerated and should not be edited by hand.

from __future__ import absolute_import

from apitools.base.protorpclite import messages as _messages
from apitools.base.py import encoding


package = 'anthosevents'


class AnthoseventsKuberunsCreateRequest(_messages.Message):
  r"""A AnthoseventsKuberunsCreateRequest object.

  Fields:
    kubeRun: A KubeRun resource to be passed as the request body.
    parent: The namespace in which this KubeRun resource should be created.
  """

  kubeRun = _messages.MessageField('KubeRun', 1)
  parent = _messages.StringField(2)


class AnthoseventsKuberunsDeleteRequest(_messages.Message):
  r"""A AnthoseventsKuberunsDeleteRequest object.

  Fields:
    name: The name of the KubeRun resource being deleted.
  """

  name = _messages.StringField(1, required=True)


class AnthoseventsKuberunsGetRequest(_messages.Message):
  r"""A AnthoseventsKuberunsGetRequest object.

  Fields:
    name: The name of the KubeRun resource being retrieved.
  """

  name = _messages.StringField(1, required=True)


class AnthoseventsKuberunsListRequest(_messages.Message):
  r"""A AnthoseventsKuberunsListRequest object.

  Fields:
    continue_: Optional encoded string to continue paging.
    fieldSelector: Allows to filter resources based on a specific value for a
      field name. Send this in a query string format. i.e.
      'metadata.name%3Dlorem'.
    labelSelector: Allows to filter resources based on a label. Supported
      operations are =, !=, exists, in, and notIn.
    limit: The maximum number of records that should be returned.
    parent: The namespace from which the KubeRun resources should be listed.
    resourceVersion: The baseline resource version from which the list or
      watch operation should start.
    watch: Flag that indicates that the client expects to watch this resource
      as well.
  """

  continue_ = _messages.StringField(1)
  fieldSelector = _messages.StringField(2)
  labelSelector = _messages.StringField(3)
  limit = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  parent = _messages.StringField(5)
  resourceVersion = _messages.StringField(6)
  watch = _messages.BooleanField(7)


class AnthoseventsKuberunsPatchRequest(_messages.Message):
  r"""A AnthoseventsKuberunsPatchRequest object.

  Fields:
    kubeRun: A KubeRun resource to be passed as the request body.
    name: The name of the KubeRun resource being updated.
  """

  kubeRun = _messages.MessageField('KubeRun', 1)
  name = _messages.StringField(2, required=True)


class AnthoseventsKuberunsReplaceKubeRunRequest(_messages.Message):
  r"""A AnthoseventsKuberunsReplaceKubeRunRequest object.

  Fields:
    kubeRun: A KubeRun resource to be passed as the request body.
    name: The name of the KubeRun resource being replaced.
  """

  kubeRun = _messages.MessageField('KubeRun', 1)
  name = _messages.StringField(2, required=True)


class AnthoseventsNamespacesCloudrunsCreateRequest(_messages.Message):
  r"""A AnthoseventsNamespacesCloudrunsCreateRequest object.

  Fields:
    cloudRun: A CloudRun resource to be passed as the request body.
    parent: The namespace in which this CloudRun resource should be created.
  """

  cloudRun = _messages.MessageField('CloudRun', 1)
  parent = _messages.StringField(2, required=True)


class AnthoseventsNamespacesCloudrunsDeleteRequest(_messages.Message):
  r"""A AnthoseventsNamespacesCloudrunsDeleteRequest object.

  Fields:
    name: The name of the CloudRun resource being deleted.
  """

  name = _messages.StringField(1, required=True)


class AnthoseventsNamespacesCloudrunsGetRequest(_messages.Message):
  r"""A AnthoseventsNamespacesCloudrunsGetRequest object.

  Fields:
    name: The name of the CloudRun resource being retrieved.
  """

  name = _messages.StringField(1, required=True)


class AnthoseventsNamespacesCloudrunsListRequest(_messages.Message):
  r"""A AnthoseventsNamespacesCloudrunsListRequest object.

  Fields:
    continue_: Optional encoded string to continue paging.
    fieldSelector: Allows to filter resources based on a specific value for a
      field name. Send this in a query string format. i.e.
      'metadata.name%3Dlorem'.
    labelSelector: Allows to filter resources based on a label. Supported
      operations are =, !=, exists, in, and notIn.
    limit: The maximum number of records that should be returned.
    parent: The namespace from which the CloudRun resources should be listed.
    resourceVersion: The baseline resource version from which the list or
      watch operation should start.
    watch: Flag that indicates that the client expects to watch this resource
      as well.
  """

  continue_ = _messages.StringField(1)
  fieldSelector = _messages.StringField(2)
  labelSelector = _messages.StringField(3)
  limit = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  parent = _messages.StringField(5, required=True)
  resourceVersion = _messages.StringField(6)
  watch = _messages.BooleanField(7)


class AnthoseventsNamespacesCloudrunsPatchRequest(_messages.Message):
  r"""A AnthoseventsNamespacesCloudrunsPatchRequest object.

  Fields:
    cloudRun: A CloudRun resource to be passed as the request body.
    name: The name of the CloudRun resource being updated.
  """

  cloudRun = _messages.MessageField('CloudRun', 1)
  name = _messages.StringField(2, required=True)


class AnthoseventsNamespacesCloudrunsReplaceCloudRunRequest(_messages.Message):
  r"""A AnthoseventsNamespacesCloudrunsReplaceCloudRunRequest object.

  Fields:
    cloudRun: A CloudRun resource to be passed as the request body.
    name: The name of the CloudRun resource being replaced.
  """

  cloudRun = _messages.MessageField('CloudRun', 1)
  name = _messages.StringField(2, required=True)


class CloudRun(_messages.Message):
  r"""CloudRun is the Schema for the CloudRuns API

  Fields:
    apiVersion: The API version for this call such as
      "events.cloud.google.com/v1beta1".
    kind: The kind of resource, in this case "CloudRun".
    metadata: Metadata associated with this CloudRun resource
    spec: The CloudRunSpec reflects the state of CloudRun
      `json:"spec,omitempty"`
    status: The CloudRunStatus defines the observed status
      `json:"status,omitempty"`
  """

  apiVersion = _messages.StringField(1)
  kind = _messages.StringField(2)
  metadata = _messages.MessageField('ObjectMeta', 3)
  spec = _messages.MessageField('CloudRunSpec', 4)
  status = _messages.MessageField('CloudRunStatus', 5)


class CloudRunSpec(_messages.Message):
  r"""CloudRunSpec defines the desired state of CloudRun

  Fields:
    eventing: `json:"eventing,omitempty"`
    networking: `json:"networking,omitempty"`
    serving: `json:"serving,omitempty"`
  """

  eventing = _messages.MessageField('EventingSpec', 1)
  networking = _messages.MessageField('NetworkingSpec', 2)
  serving = _messages.MessageField('ServingSpec', 3)


class CloudRunStatus(_messages.Message):
  r"""CloudRunStatus defines the observed state of CloudRun

  Messages:
    AnnotationsValue: Annotations is additional Status fields for the Resource
      to save some additional State as well as convey more information to the
      user. This is roughly akin to Annotations on any k8s resource, just the
      reconciler conveying richer information outwards.

  Fields:
    annotations: Annotations is additional Status fields for the Resource to
      save some additional State as well as convey more information to the
      user. This is roughly akin to Annotations on any k8s resource, just the
      reconciler conveying richer information outwards.
    conditions: Conditions are the latest available observations of a
      resource's current state.
    eventingversion: The version of the installed release.
    istioversion: The version of the installed release.
    observedGeneration: ObservedGeneration is the 'Generation' of the Service
      that was last processed by the controller.
    servingversion: The version of the installed release.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""Annotations is additional Status fields for the Resource to save some
    additional State as well as convey more information to the user. This is
    roughly akin to Annotations on any k8s resource, just the reconciler
    conveying richer information outwards.

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  conditions = _messages.MessageField('Condition', 2, repeated=True)
  eventingversion = _messages.StringField(3)
  istioversion = _messages.StringField(4)
  observedGeneration = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  servingversion = _messages.StringField(6)


class Condition(_messages.Message):
  r"""Condition defines a generic condition for a Resource

  Fields:
    lastTransitionTime: Optional. Last time the condition transitioned from
      one status to another.
    message: Optional. Human readable message indicating details about the
      current status.
    reason: Optional. One-word CamelCase reason for the condition's last
      transition.
    severity: Optional. How to interpret failures of this condition, one of
      Error, Warning, Info
    status: Status of the condition, one of True, False, Unknown.
    type: type is used to communicate the status of the reconciliation
      process. See also: https://github.com/knative/serving/blob/master/docs/s
      pec/errors.md#error-conditions-and-reporting Types common to all
      resources include: * "Ready": True when the Resource is ready.
  """

  lastTransitionTime = _messages.StringField(1)
  message = _messages.StringField(2)
  reason = _messages.StringField(3)
  severity = _messages.StringField(4)
  status = _messages.StringField(5)
  type = _messages.StringField(6)


class Empty(_messages.Message):
  r"""A generic empty message that you can re-use to avoid defining duplicated
  empty messages in your APIs. A typical example is to use it as the request
  or the response type of an API method. For instance: service Foo { rpc
  Bar(google.protobuf.Empty) returns (google.protobuf.Empty); } The JSON
  representation for `Empty` is empty JSON object `{}`.
  """



class EventingSpec(_messages.Message):
  r"""EventingSpec defines the desired state of Eventing

  Fields:
    enabled: A boolean attribute.
  """

  enabled = _messages.BooleanField(1)


class KubeRun(_messages.Message):
  r"""KubeRun is the Schema for the KubeRuns API

  Fields:
    apiVersion: The API version for this call such as
      "events.cloud.google.com/v1beta1".
    kind: The kind of resource, in this case "KubeRun".
    metadata: Metadata associated with this KubeRun resource
    spec: The KubeRunSpec reflects the state of KubeRun
    status: The KubeRunStatus defines the observed status
  """

  apiVersion = _messages.StringField(1)
  kind = _messages.StringField(2)
  metadata = _messages.MessageField('ObjectMeta', 3)
  spec = _messages.MessageField('CloudRunSpec', 4)
  status = _messages.MessageField('KubeRunStatus', 5)


class KubeRunStatus(_messages.Message):
  r"""KubeRunStatus defines the observed state of KubeRun

  Messages:
    AnnotationsValue: Annotations is additional Status fields for the Resource
      to save some additional State as well as convey more information to the
      user. This is roughly akin to Annotations on any k8s resource, just the
      reconciler conveying richer information outwards.

  Fields:
    annotations: Annotations is additional Status fields for the Resource to
      save some additional State as well as convey more information to the
      user. This is roughly akin to Annotations on any k8s resource, just the
      reconciler conveying richer information outwards.
    conditions: Conditions are the latest available observations of a
      resource's current state.
    eventingversion: The version of the installed release.
    istioversion: The version of the installed release.
    observedGeneration: ObservedGeneration is the 'Generation' of the Service
      that was last processed by the controller.
    servingversion: The version of the installed release.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""Annotations is additional Status fields for the Resource to save some
    additional State as well as convey more information to the user. This is
    roughly akin to Annotations on any k8s resource, just the reconciler
    conveying richer information outwards.

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  conditions = _messages.MessageField('Condition', 2, repeated=True)
  eventingversion = _messages.StringField(3)
  istioversion = _messages.StringField(4)
  observedGeneration = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  servingversion = _messages.StringField(6)


class ListCloudRunsResponse(_messages.Message):
  r"""ListCloudRunsResponse is a list of CloudRun resources. The next page
  token is specified as the "continue" field in ListMeta.

  Fields:
    apiVersion: The API version for this call such as "core/v1".
    items: A CloudRun attribute.
    kind: The kind of this resource, in this case "CloudRunList".
    metadata: Metadata associated with this CloudRun list.
  """

  apiVersion = _messages.StringField(1)
  items = _messages.MessageField('CloudRun', 2, repeated=True)
  kind = _messages.StringField(3)
  metadata = _messages.MessageField('ListMeta', 4)


class ListKubeRunsResponse(_messages.Message):
  r"""ListKubeRunsResponse is a list of KubeRun resources. The next page token
  is specified as the "continue" field in ListMeta.

  Fields:
    apiVersion: The API version for this call such as "core/v1".
    items: A KubeRun attribute.
    kind: The kind of this resource, in this case "KubeRunList".
    metadata: Metadata associated with this KubeRun list.
  """

  apiVersion = _messages.StringField(1)
  items = _messages.MessageField('KubeRun', 2, repeated=True)
  kind = _messages.StringField(3)
  metadata = _messages.MessageField('ListMeta', 4)


class ListMeta(_messages.Message):
  r"""ListMeta describes metadata that synthetic resources must have,
  including lists and various status objects. A resource may have only one of
  {ObjectMeta, ListMeta}.

  Fields:
    continue_: continue may be set if the user set a limit on the number of
      items returned, and indicates that the server has more data available.
      The value is opaque and may be used to issue another request to the
      endpoint that served this list to retrieve the next set of available
      objects. Continuing a list may not be possible if the server
      configuration has changed or more than a few minutes have passed. The
      resourceVersion field returned when using this continue value will be
      identical to the value in the first response.
    resourceVersion: String that identifies the server's internal version of
      this object that can be used by clients to determine when objects have
      changed. Value must be treated as opaque by clients and passed
      unmodified back to the server. Populated by the system. Read-only. More
      info: https://git.k8s.io/community/contributors/devel/api-
      conventions.md#concurrency-control-and-consistency +optional
    selfLink: SelfLink is a URL representing this object. Populated by the
      system. Read-only. +optional
  """

  continue_ = _messages.StringField(1)
  resourceVersion = _messages.StringField(2)
  selfLink = _messages.StringField(3)


class NetworkingSpec(_messages.Message):
  r"""NetworkingSpec defines the desired state of Networking

  Fields:
    enabled: A boolean attribute.
    loadbalancertype: LoadBalancerType is whether the istio ingress is
      internal or external possible values are internal | external(implicit).
  """

  enabled = _messages.BooleanField(1)
  loadbalancertype = _messages.StringField(2)


class ObjectMeta(_messages.Message):
  r"""k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta is metadata that all
  persisted resources must have, which includes all objects users must create.

  Messages:
    AnnotationsValue: (Optional) Annotations is an unstructured key value map
      stored with a resource that may be set by external tools to store and
      retrieve arbitrary metadata. They are not queryable and should be
      preserved when modifying objects. More info:
      http://kubernetes.io/docs/user-guide/annotations
    LabelsValue: (Optional) Map of string keys and values that can be used to
      organize and categorize (scope and select) objects. May match selectors
      of replication controllers and routes. More info:
      http://kubernetes.io/docs/user-guide/labels

  Fields:
    annotations: (Optional) Annotations is an unstructured key value map
      stored with a resource that may be set by external tools to store and
      retrieve arbitrary metadata. They are not queryable and should be
      preserved when modifying objects. More info:
      http://kubernetes.io/docs/user-guide/annotations
    clusterName: (Optional) Cloud Run fully managed: not supported Cloud Run
      for Anthos: supported The name of the cluster which the object belongs
      to. This is used to distinguish resources with same name and namespace
      in different clusters. This field is not set anywhere right now and
      apiserver is going to ignore it if set in create or update request.
    creationTimestamp: (Optional) CreationTimestamp is a timestamp
      representing the server time when this object was created. It is not
      guaranteed to be set in happens-before order across separate operations.
      Clients may not set this value. It is represented in RFC3339 form and is
      in UTC. Populated by the system. Read-only. Null for lists. More info:
      https://git.k8s.io/community/contributors/devel/api-
      conventions.md#metadata
    deletionGracePeriodSeconds: (Optional) Cloud Run fully managed: not
      supported Cloud Run for Anthos: supported Number of seconds allowed for
      this object to gracefully terminate before it will be removed from the
      system. Only set when deletionTimestamp is also set. May only be
      shortened. Read-only.
    deletionTimestamp: (Optional) Cloud Run fully managed: not supported Cloud
      Run for Anthos: supported DeletionTimestamp is RFC 3339 date and time at
      which this resource will be deleted. This field is set by the server
      when a graceful deletion is requested by the user, and is not directly
      settable by a client. The resource is expected to be deleted (no longer
      visible from resource lists, and not reachable by name) after the time
      in this field, once the finalizers list is empty. As long as the
      finalizers list contains items, deletion is blocked. Once the
      deletionTimestamp is set, this value may not be unset or be set further
      into the future, although it may be shortened or the resource may be
      deleted prior to this time. For example, a user may request that a pod
      is deleted in 30 seconds. The Kubelet will react by sending a graceful
      termination signal to the containers in the pod. After that 30 seconds,
      the Kubelet will send a hard termination signal (SIGKILL) to the
      container and after cleanup, remove the pod from the API. In the
      presence of network partitions, this object may still exist after this
      timestamp, until an administrator or automated process can determine the
      resource is fully terminated. If not set, graceful deletion of the
      object has not been requested. Populated by the system when a graceful
      deletion is requested. Read-only. More info:
      https://git.k8s.io/community/contributors/devel/api-
      conventions.md#metadata
    finalizers: (Optional) Cloud Run fully managed: not supported Cloud Run
      for Anthos: supported Must be empty before the object is deleted from
      the registry. Each entry is an identifier for the responsible component
      that will remove the entry from the list. If the deletionTimestamp of
      the object is non-nil, entries in this list can only be removed.
      +patchStrategy=merge
    generateName: (Optional) Cloud Run fully managed: not supported Cloud Run
      for Anthos: supported GenerateName is an optional prefix, used by the
      server, to generate a unique name ONLY IF the Name field has not been
      provided. If this field is used, the name returned to the client will be
      different than the name passed. This value will also be combined with a
      unique suffix. The provided value has the same validation rules as the
      Name field, and may be truncated by the length of the suffix required to
      make the value unique on the server. If this field is specified and the
      generated name exists, the server will NOT return a 409 - instead, it
      will either return 201 Created or 500 with Reason ServerTimeout
      indicating a unique name could not be found in the time allotted, and
      the client should retry (optionally after the time indicated in the
      Retry-After header). Applied only if Name is not specified. More info:
      https://git.k8s.io/community/contributors/devel/api-
      conventions.md#idempotency string generateName = 2;
    generation: (Optional) A sequence number representing a specific
      generation of the desired state. Populated by the system. Read-only.
    labels: (Optional) Map of string keys and values that can be used to
      organize and categorize (scope and select) objects. May match selectors
      of replication controllers and routes. More info:
      http://kubernetes.io/docs/user-guide/labels
    name: Name must be unique within a namespace, within a Cloud Run region.
      Is required when creating resources, although some resources may allow a
      client to request the generation of an appropriate name automatically.
      Name is primarily intended for creation idempotence and configuration
      definition. Cannot be updated. More info:
      http://kubernetes.io/docs/user-guide/identifiers#names +optional
    namespace: Namespace defines the space within each name must be unique,
      within a Cloud Run region. In Cloud Run the namespace must be equal to
      either the project ID or project number.
    ownerReferences: (Optional) Cloud Run fully managed: not supported Cloud
      Run for Anthos: supported List of objects that own this object. If ALL
      objects in the list have been deleted, this object will be garbage
      collected.
    resourceVersion: (Optional) An opaque value that represents the internal
      version of this object that can be used by clients to determine when
      objects have changed. May be used for optimistic concurrency, change
      detection, and the watch operation on a resource or set of resources.
      Clients must treat these values as opaque and passed unmodified back to
      the server. They may only be valid for a particular resource or set of
      resources. Populated by the system. Read-only. Value must be treated as
      opaque by clients and . More info:
      https://git.k8s.io/community/contributors/devel/api-
      conventions.md#concurrency-control-and-consistency
    selfLink: (Optional) SelfLink is a URL representing this object. Populated
      by the system. Read-only. string selfLink = 4;
    uid: (Optional) UID is the unique in time and space value for this object.
      It is typically generated by the server on successful creation of a
      resource and is not allowed to change on PUT operations. Populated by
      the system. Read-only. More info: http://kubernetes.io/docs/user-
      guide/identifiers#uids
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""(Optional) Annotations is an unstructured key value map stored with a
    resource that may be set by external tools to store and retrieve arbitrary
    metadata. They are not queryable and should be preserved when modifying
    objects. More info: http://kubernetes.io/docs/user-guide/annotations

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""(Optional) Map of string keys and values that can be used to organize
    and categorize (scope and select) objects. May match selectors of
    replication controllers and routes. More info:
    http://kubernetes.io/docs/user-guide/labels

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  clusterName = _messages.StringField(2)
  creationTimestamp = _messages.StringField(3)
  deletionGracePeriodSeconds = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  deletionTimestamp = _messages.StringField(5)
  finalizers = _messages.StringField(6, repeated=True)
  generateName = _messages.StringField(7)
  generation = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  labels = _messages.MessageField('LabelsValue', 9)
  name = _messages.StringField(10)
  namespace = _messages.StringField(11)
  ownerReferences = _messages.MessageField('OwnerReference', 12, repeated=True)
  resourceVersion = _messages.StringField(13)
  selfLink = _messages.StringField(14)
  uid = _messages.StringField(15)


class OwnerReference(_messages.Message):
  r"""OwnerReference contains enough information to let you identify an owning
  object. Currently, an owning object must be in the same namespace, so there
  is no namespace field.

  Fields:
    apiVersion: API version of the referent.
    blockOwnerDeletion: If true, AND if the owner has the "foregroundDeletion"
      finalizer, then the owner cannot be deleted from the key-value store
      until this reference is removed. Defaults to false. To set this field, a
      user needs "delete" permission of the owner, otherwise 422
      (Unprocessable Entity) will be returned. +optional
    controller: If true, this reference points to the managing controller.
      +optional
    kind: Kind of the referent. More info:
      https://git.k8s.io/community/contributors/devel/api-
      conventions.md#types-kinds
    name: Name of the referent. More info: http://kubernetes.io/docs/user-
      guide/identifiers#names
    uid: UID of the referent. More info: http://kubernetes.io/docs/user-
      guide/identifiers#uids
  """

  apiVersion = _messages.StringField(1)
  blockOwnerDeletion = _messages.BooleanField(2)
  controller = _messages.BooleanField(3)
  kind = _messages.StringField(4)
  name = _messages.StringField(5)
  uid = _messages.StringField(6)


class ServingSpec(_messages.Message):
  r"""ServingSpec defines the desired state of Serving

  Fields:
    enabled: A boolean attribute.
  """

  enabled = _messages.BooleanField(1)


class StandardQueryParameters(_messages.Message):
  r"""Query parameters accepted by all methods.

  Enums:
    FXgafvValueValuesEnum: V1 error format.
    AltValueValuesEnum: Data format for response.

  Fields:
    f__xgafv: V1 error format.
    access_token: OAuth access token.
    alt: Data format for response.
    callback: JSONP
    fields: Selector specifying which fields to include in a partial response.
    key: API key. Your API key identifies your project and provides you with
      API access, quota, and reports. Required unless you provide an OAuth 2.0
      token.
    oauth_token: OAuth 2.0 token for the current user.
    prettyPrint: Returns response with indentations and line breaks.
    quotaUser: Available to use for quota purposes for server-side
      applications. Can be any arbitrary string assigned to a user, but should
      not exceed 40 characters.
    trace: A tracing token of the form "token:<tokenid>" to include in api
      requests.
    uploadType: Legacy upload protocol for media (e.g. "media", "multipart").
    upload_protocol: Upload protocol for media (e.g. "raw", "multipart").
  """

  class AltValueValuesEnum(_messages.Enum):
    r"""Data format for response.

    Values:
      json: Responses with Content-Type of application/json
      media: Media download with context-dependent Content-Type
      proto: Responses with Content-Type of application/x-protobuf
    """
    json = 0
    media = 1
    proto = 2

  class FXgafvValueValuesEnum(_messages.Enum):
    r"""V1 error format.

    Values:
      _1: v1 error format
      _2: v2 error format
    """
    _1 = 0
    _2 = 1

  f__xgafv = _messages.EnumField('FXgafvValueValuesEnum', 1)
  access_token = _messages.StringField(2)
  alt = _messages.EnumField('AltValueValuesEnum', 3, default='json')
  callback = _messages.StringField(4)
  fields = _messages.StringField(5)
  key = _messages.StringField(6)
  oauth_token = _messages.StringField(7)
  prettyPrint = _messages.BooleanField(8, default=True)
  quotaUser = _messages.StringField(9)
  trace = _messages.StringField(10)
  uploadType = _messages.StringField(11)
  upload_protocol = _messages.StringField(12)


encoding.AddCustomJsonFieldMapping(
    ListMeta, 'continue_', 'continue')
encoding.AddCustomJsonFieldMapping(
    StandardQueryParameters, 'f__xgafv', '$.xgafv')
encoding.AddCustomJsonEnumMapping(
    StandardQueryParameters.FXgafvValueValuesEnum, '_1', '1')
encoding.AddCustomJsonEnumMapping(
    StandardQueryParameters.FXgafvValueValuesEnum, '_2', '2')



# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Implementation of update command for updating bucket settings."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import arg_parsers
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.storage import flags
from googlecloudsdk.command_lib.storage import user_request_args_factory
from googlecloudsdk.command_lib.storage import wildcard_iterator
from googlecloudsdk.command_lib.storage.tasks import task_executor
from googlecloudsdk.command_lib.storage.tasks import task_graph_executor
from googlecloudsdk.command_lib.storage.tasks import task_status
from googlecloudsdk.command_lib.storage.tasks.buckets import update_bucket_task


_CORS_HELP_TEXT = """
Sets the Cross-Origin Resource Sharing (CORS) configuration on a bucket.
An example CORS JSON document looks like the following:

  [
    {
      "origin": ["http://origin1.example.com"],
      "responseHeader": ["Content-Type"],
      "method": ["GET"],
      "maxAgeSeconds": 3600
    }
  ]

For more information about supported endpoints for CORS, see
[Cloud Storage CORS support]
(https://cloud.google.com/storage/docs/cross-origin#server-side-support).
"""
_LABELS_HELP_TEXT = """
Sets the label configuration for the bucket. An example label JSON document
looks like the following:

  {
    "your_label_key": "your_label_value",
    "your_other_label_key": "your_other_label_value"
  }
"""
_LIFECYCLE_HELP_TEXT = """
Sets the lifecycle management configuration on a bucket. For example,
The following lifecycle management configuration JSON document
specifies that all objects in this bucket that are more than 365 days
old are deleted automatically:

  {
    "rule":
    [
      {
        "action": {"type": "Delete"},
        "condition": {"age": 365}
      }
    ]
  }
"""


@base.Hidden
class Update(base.Command):
  """Update bucket settings."""

  detailed_help = {
      'DESCRIPTION':
          """
      Update a bucket.
      """,
      'EXAMPLES':
          """

      The following command updates the retention period of a Cloud Storage
      bucket named "my-bucket" to one year and thirty-six minutes:

        $ {command} gs://my-bucket --retention-period 1y36m

      The following command clears the retention period of a bucket:

        $ {command} gs://my-bucket --clear-retention-period
      """,
  }

  @staticmethod
  def Args(parser):
    parser.add_argument(
        'url', nargs='+', type=str, help='The URLs of the buckets to update.')
    parser.add_argument(
        '--clear-cors',
        action='store_true',
        help="Clears the bucket's CORS settings.")
    parser.add_argument('--cors-file', help=_CORS_HELP_TEXT)
    parser.add_argument(
        '--default-storage-class',
        help='Sets the default storage class for the bucket.')
    parser.add_argument(
        '--default-encryption-key',
        help='Set the default KMS key for the bucket.')
    parser.add_argument(
        '--clear-default-encryption-key',
        action='store_true',
        help="Clears the bucket's default encryption key.")
    labels = parser.add_mutually_exclusive_group()
    labels.add_argument('--labels-file', help=_LABELS_HELP_TEXT)
    update_labels = labels.add_group()
    update_labels.add_argument(
        '--update-labels',
        metavar='LABEL_KEYS_AND_VALUES',
        type=arg_parsers.ArgDict(),
        help='Add or update labels. Example:'
        ' --update-labels=key1=value1,key2=value2')
    update_labels.add_argument(
        '--remove-labels',
        metavar='LABEL_KEYS',
        type=arg_parsers.ArgList(),
        help='Remove labels by their key names.')
    labels.add_argument(
        '--clear-labels',
        action='store_true',
        help='Clear all labels associated with a bucket.')
    parser.add_argument('--lifecycle-file', help=_LIFECYCLE_HELP_TEXT)
    parser.add_argument(
        '--clear-lifecycle',
        action='store_true',
        help='Removes all lifecycle configuration for the bucket.')
    parser.add_argument(
        '--log-bucket',
        help='Enables usage logging of the bucket, outputting log files to the'
        " specified logging_bucket in this flag. Cloud Storage doesn't validate"
        ' the existence of the bucket receiving logs. In addition to enabling'
        ' logging on your bucket, you will also need to grant'
        ' cloud-storage-analytics@google.com write access to the log bucket.')
    parser.add_argument(
        '--clear-log-bucket',
        action='store_true',
        help="Clears logging bucket receiving the usage current bucket's data.")
    parser.add_argument(
        '--log-object-prefix',
        help='Specifies the object prefix for logging activity to the log'
        ' bucket. The default prefix is the bucket name. All read and write'
        ' activity to objects in the bucket will be logged for objects matching'
        ' the prefix.')
    parser.add_argument(
        '--clear-log-object-prefix',
        action='store_true',
        help='Clears prefix used to determine what usage data to send to'
        ' logging bucket.')
    parser.add_argument(
        '--requester-pays',
        action=arg_parsers.StoreTrueFalseAction,
        help='Allows you to configure a Cloud Storage bucket so that the'
        ' requester pays all costs related to accessing the bucket and its'
        ' objects.')
    parser.add_argument(
        '--retention-period',
        help='Minimum [retention period](https://cloud.google.com'
        '/storage/docs/bucket-lock#retention-periods)'
        ' for objects stored in the bucket, for example'
        ' ``--retention-period=1Y1M1D5S\'\'. Objects added to the bucket'
        ' cannot be deleted until they\'ve been stored for the specified'
        ' length of time. Default is no retention period. Only available'
        ' for Cloud Storage using the JSON API.')
    parser.add_argument(
        '--clear-retention-period',
        action='store_true',
        help='Clears the object retention period for a bucket.')
    parser.add_argument(
        '--lock-retention-period',
        action=arg_parsers.StoreTrueFalseAction,
        help='Locks an unlocked retention policy on the buckets. Caution: A'
        ' locked retention policy cannot be removed from a bucket or reduced in'
        ' duration. Once locked, deleting the bucket is the only way to'
        ' "remove" a retention policy.')
    parser.add_argument(
        '--default-event-based-hold',
        action=arg_parsers.StoreTrueFalseAction,
        help='Sets the default value for an event-based hold on the bucket.'
        ' By setting the default event-based hold on a bucket, newly-created'
        ' objects inherit that value as their event-based hold (it is not'
        ' applied retroactively).')
    parser.add_argument(
        '--versioning',
        action=arg_parsers.StoreTrueFalseAction,
        help='Allows you to configure a Cloud Storage bucket to keep old'
        ' versions of objects.')
    parser.add_argument(
        '--uniform-bucket-level-access',
        action=arg_parsers.StoreTrueFalseAction,
        help='Enables or disables [uniform bucket-level access]'
        '(https://cloud.google.com/storage/docs/bucket-policy-only)'
        ' for the buckets.')
    parser.add_argument(
        '--web-main-page-suffix',
        help='Cloud Storage allows you to configure a bucket to behave like a'
        ' static website. A subsequent GET bucket request through a custom'
        ' domain serves the specified "main" page instead of performing the'
        ' usual bucket listing.')
    parser.add_argument(
        '--clear-web-main-page-suffix',
        help='Clear website main page suffix if bucket is hosting website.')
    parser.add_argument(
        '--web-error-page',
        help='Cloud Storage allows you to configure a bucket to behave like a'
        ' static website. A subsequent GET bucket request through a custom'
        ' domain for a non-existent object serves the specified error page'
        ' instead of the standard Cloud Storage error.')
    parser.add_argument(
        '--clear-web-error-page',
        help='Clear website error page if bucket is hosting website.')
    flags.add_continue_on_error_flag(parser)

  def update_task_iterator(self, args):
    user_request_args = (
        user_request_args_factory.get_user_request_args_from_command_args(
            args, metadata_type=user_request_args_factory.MetadataType.BUCKET))
    for url in args.url:
      for resource in wildcard_iterator.get_wildcard_iterator(url):
        yield update_bucket_task.UpdateBucketTask(
            resource, user_request_args=user_request_args)

  def Run(self, args):
    task_status_queue = task_graph_executor.multiprocessing_context.Queue()
    self.exit_code = task_executor.execute_tasks(
        self.update_task_iterator(args),
        parallelizable=True,
        task_status_queue=task_status_queue,
        progress_type=task_status.ProgressType.COUNT,
        continue_on_error=args.continue_on_error,
    )



"""Generated message classes for transcoder version v1beta1.

This API converts video files into formats suitable for consumer distribution.
"""
# NOTE: This file is autogenerated and should not be edited by hand.

from __future__ import absolute_import

from apitools.base.protorpclite import messages as _messages
from apitools.base.py import encoding


package = 'transcoder'


class AdBreak(_messages.Message):
  r"""Ad break.

  Fields:
    startTimeOffset: Start time in seconds for the ad break, relative to the
      output file timeline. The default is `0s`.
  """

  startTimeOffset = _messages.StringField(1)


class Aes128Encryption(_messages.Message):
  r"""Configuration for AES-128 encryption.

  Fields:
    keyUri: Required. URI of the key delivery service. This URI is inserted
      into the M3U8 header.
  """

  keyUri = _messages.StringField(1)


class Animation(_messages.Message):
  r"""Animation types.

  Fields:
    animationEnd: End previous animation.
    animationFade: Display overlay object with fade animation.
    animationStatic: Display static overlay object.
  """

  animationEnd = _messages.MessageField('AnimationEnd', 1)
  animationFade = _messages.MessageField('AnimationFade', 2)
  animationStatic = _messages.MessageField('AnimationStatic', 3)


class AnimationEnd(_messages.Message):
  r"""End previous overlay animation from the video. Without AnimationEnd, the
  overlay object will keep the state of previous animation until the end of
  the video.

  Fields:
    startTimeOffset: The time to end overlay object, in seconds. Default: 0
  """

  startTimeOffset = _messages.StringField(1)


class AnimationFade(_messages.Message):
  r"""Display overlay object with fade animation.

  Enums:
    FadeTypeValueValuesEnum: Required. Type of fade animation: `FADE_IN` or
      `FADE_OUT`.

  Fields:
    endTimeOffset: The time to end the fade animation, in seconds. Default:
      `start_time_offset` + 1s
    fadeType: Required. Type of fade animation: `FADE_IN` or `FADE_OUT`.
    startTimeOffset: The time to start the fade animation, in seconds.
      Default: 0
    xy: Normalized coordinates based on output video resolution. Valid values:
      `0.0`\u2013`1.0`. `xy` is the upper-left coordinate of the overlay
      object. For example, use the x and y coordinates {0,0} to position the
      top-left corner of the overlay animation in the top-left corner of the
      output video.
  """

  class FadeTypeValueValuesEnum(_messages.Enum):
    r"""Required. Type of fade animation: `FADE_IN` or `FADE_OUT`.

    Values:
      FADE_TYPE_UNSPECIFIED: The fade type is not specified.
      FADE_IN: Fade the overlay object into view.
      FADE_OUT: Fade the overlay object out of view.
    """
    FADE_TYPE_UNSPECIFIED = 0
    FADE_IN = 1
    FADE_OUT = 2

  endTimeOffset = _messages.StringField(1)
  fadeType = _messages.EnumField('FadeTypeValueValuesEnum', 2)
  startTimeOffset = _messages.StringField(3)
  xy = _messages.MessageField('NormalizedCoordinate', 4)


class AnimationStatic(_messages.Message):
  r"""Display static overlay object.

  Fields:
    startTimeOffset: The time to start displaying the overlay object, in
      seconds. Default: 0
    xy: Normalized coordinates based on output video resolution. Valid values:
      `0.0`\u2013`1.0`. `xy` is the upper-left coordinate of the overlay
      object. For example, use the x and y coordinates {0,0} to position the
      top-left corner of the overlay animation in the top-left corner of the
      output video.
  """

  startTimeOffset = _messages.StringField(1)
  xy = _messages.MessageField('NormalizedCoordinate', 2)


class Audio(_messages.Message):
  r"""Audio preprocessing configuration.

  Fields:
    highBoost: Enable boosting high frequency components. The default is
      `false`.
    lowBoost: Enable boosting low frequency components. The default is
      `false`.
    lufs: Specify audio loudness normalization in loudness units relative to
      full scale (LUFS). Enter a value between -24 and 0 (the default), where:
      * -24 is the Advanced Television Systems Committee (ATSC A/85) standard
      * -23 is the EU R128 broadcast standard * -19 is the prior standard for
      online mono audio * -18 is the ReplayGain standard * -16 is the prior
      standard for stereo audio * -14 is the new online audio standard
      recommended by Spotify, as well as Amazon Echo * 0 disables
      normalization
  """

  highBoost = _messages.BooleanField(1)
  lowBoost = _messages.BooleanField(2)
  lufs = _messages.FloatField(3)


class AudioAtom(_messages.Message):
  r"""The mapping for the `Job.edit_list` atoms with audio `EditAtom.inputs`.

  Fields:
    channels: List of `Channel`s for this audio stream. for in-depth
      explanation.
    key: Required. The `EditAtom.key` that references the atom with audio
      inputs in the `Job.edit_list`.
  """

  channels = _messages.MessageField('AudioChannel', 1, repeated=True)
  key = _messages.StringField(2)


class AudioChannel(_messages.Message):
  r"""The audio channel.

  Fields:
    inputs: List of `Job.inputs` for this audio channel.
  """

  inputs = _messages.MessageField('AudioChannelInput', 1, repeated=True)


class AudioChannelInput(_messages.Message):
  r"""Identifies which input file, track, and channel should be used.

  Fields:
    channel: Required. The zero-based index of the channel in the input file.
    gainDb: Audio volume control in dB. Negative values decrease volume,
      positive values increase. The default is 0.
    key: Required. The `Input.key` that identifies the input file.
    track: Required. The zero-based index of the track in the input file.
  """

  channel = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  gainDb = _messages.FloatField(2)
  key = _messages.StringField(3)
  track = _messages.IntegerField(4, variant=_messages.Variant.INT32)


class AudioStream(_messages.Message):
  r"""Audio stream resource.

  Fields:
    bitrateBps: Required. Audio bitrate in bits per second. Must be between 1
      and 10,000,000.
    channelCount: Number of audio channels. Must be between 1 and 6. The
      default is 2.
    channelLayout: A list of channel names specifying layout of the audio
      channels. This only affects the metadata embedded in the container
      headers, if supported by the specified format. The default is `["fl",
      "fr"]`. Supported channel names: - 'fl' - Front left channel - 'fr' -
      Front right channel - 'sl' - Side left channel - 'sr' - Side right
      channel - 'fc' - Front center channel - 'lfe' - Low frequency
    codec: The codec for this audio stream. The default is `"aac"`. Supported
      audio codecs: - 'aac' - 'aac-he' - 'aac-he-v2' - 'mp3' - 'ac3' - 'eac3'
    mapping: The mapping for the `Job.edit_list` atoms with audio
      `EditAtom.inputs`.
    sampleRateHertz: The audio sample rate in Hertz. The default is 48000
      Hertz.
  """

  bitrateBps = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  channelCount = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  channelLayout = _messages.StringField(3, repeated=True)
  codec = _messages.StringField(4)
  mapping = _messages.MessageField('AudioAtom', 5, repeated=True)
  sampleRateHertz = _messages.IntegerField(6, variant=_messages.Variant.INT32)


class Color(_messages.Message):
  r"""Color preprocessing configuration.

  Fields:
    brightness: Control brightness of the video. Enter a value between -1 and
      1, where -1 is minimum brightness and 1 is maximum brightness. 0 is no
      change. The default is 0.
    contrast: Control black and white contrast of the video. Enter a value
      between -1 and 1, where -1 is minimum contrast and 1 is maximum
      contrast. 0 is no change. The default is 0.
    saturation: Control color saturation of the video. Enter a value between
      -1 and 1, where -1 is fully desaturated and 1 is maximum saturation. 0
      is no change. The default is 0.
  """

  brightness = _messages.FloatField(1)
  contrast = _messages.FloatField(2)
  saturation = _messages.FloatField(3)


class Crop(_messages.Message):
  r"""Video cropping configuration for the input video. The cropped input
  video is scaled to match the output resolution.

  Fields:
    bottomPixels: The number of pixels to crop from the bottom. The default is
      0.
    leftPixels: The number of pixels to crop from the left. The default is 0.
    rightPixels: The number of pixels to crop from the right. The default is
      0.
    topPixels: The number of pixels to crop from the top. The default is 0.
  """

  bottomPixels = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  leftPixels = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  rightPixels = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  topPixels = _messages.IntegerField(4, variant=_messages.Variant.INT32)


class Deblock(_messages.Message):
  r"""Deblock preprocessing configuration.

  Fields:
    enabled: Enable deblocker. The default is `false`.
    strength: Set strength of the deblocker. Enter a value between 0 and 1.
      The higher the value, the stronger the block removal. 0 is no
      deblocking. The default is 0.
  """

  enabled = _messages.BooleanField(1)
  strength = _messages.FloatField(2)


class Denoise(_messages.Message):
  r"""Denoise preprocessing configuration.

  Fields:
    strength: Set strength of the denoise. Enter a value between 0 and 1. The
      higher the value, the smoother the image. 0 is no denoising. The default
      is 0.
    tune: Set the denoiser mode. The default is `"standard"`. Supported
      denoiser modes: - 'standard' - 'grain'
  """

  strength = _messages.FloatField(1)
  tune = _messages.StringField(2)


class EditAtom(_messages.Message):
  r"""Edit atom.

  Fields:
    endTimeOffset: End time in seconds for the atom, relative to the input
      file timeline. When `end_time_offset` is not specified, the `inputs` are
      used until the end of the atom.
    inputs: List of `Input.key`s identifying files that should be used in this
      atom. The listed `inputs` must have the same timeline.
    key: A unique key for this atom. Must be specified when using advanced
      mapping.
    startTimeOffset: Start time in seconds for the atom, relative to the input
      file timeline. The default is `0s`.
  """

  endTimeOffset = _messages.StringField(1)
  inputs = _messages.StringField(2, repeated=True)
  key = _messages.StringField(3)
  startTimeOffset = _messages.StringField(4)


class ElementaryStream(_messages.Message):
  r"""Encoding of an input file such as an audio, video, or text track.
  Elementary streams must be packaged before mapping and sharing between
  different output formats.

  Fields:
    audioStream: Encoding of an audio stream.
    key: A unique key for this elementary stream.
    textStream: Encoding of a text stream. For example, closed captions or
      subtitles.
    videoStream: Encoding of a video stream.
  """

  audioStream = _messages.MessageField('AudioStream', 1)
  key = _messages.StringField(2)
  textStream = _messages.MessageField('TextStream', 3)
  videoStream = _messages.MessageField('VideoStream', 4)


class Empty(_messages.Message):
  r"""A generic empty message that you can re-use to avoid defining duplicated
  empty messages in your APIs. A typical example is to use it as the request
  or the response type of an API method. For instance: service Foo { rpc
  Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
  """



class Encryption(_messages.Message):
  r"""Encryption settings.

  Fields:
    aes128: Configuration for AES-128 encryption.
    iv: Required. 128 bit Initialization Vector (IV) represented as lowercase
      hexadecimal digits.
    key: Required. 128 bit encryption key represented as lowercase hexadecimal
      digits.
    mpegCenc: Configuration for MPEG Common Encryption (MPEG-CENC).
    sampleAes: Configuration for SAMPLE-AES encryption.
  """

  aes128 = _messages.MessageField('Aes128Encryption', 1)
  iv = _messages.StringField(2)
  key = _messages.StringField(3)
  mpegCenc = _messages.MessageField('MpegCommonEncryption', 4)
  sampleAes = _messages.MessageField('SampleAesEncryption', 5)


class FailureDetail(_messages.Message):
  r"""Additional information about the reasons for the failure.

  Fields:
    description: A description of the failure.
  """

  description = _messages.StringField(1)


class Image(_messages.Message):
  r"""Overlaid jpeg image.

  Fields:
    alpha: Target image opacity. Valid values are from `1.0` (solid, default)
      to `0.0` (transparent), exclusive. Set this to a value greater than
      `0.0`.
    resolution: Normalized image resolution, based on output video resolution.
      Valid values: `0.0`\u2013`1.0`. To respect the original image aspect
      ratio, set either `x` or `y` to `0.0`. To use the original image
      resolution, set both `x` and `y` to `0.0`.
    uri: Required. URI of the JPEG image in Cloud Storage. For example,
      `gs://bucket/inputs/image.jpeg`. JPEG is the only supported image type.
  """

  alpha = _messages.FloatField(1)
  resolution = _messages.MessageField('NormalizedCoordinate', 2)
  uri = _messages.StringField(3)


class Input(_messages.Message):
  r"""Input asset.

  Fields:
    key: A unique key for this input. Must be specified when using advanced
      mapping and edit lists.
    preprocessingConfig: Preprocessing configurations.
    uri: URI of the media. Input files must be at least 5 seconds in duration
      and stored in Cloud Storage (for example,
      `gs://bucket/inputs/file.mp4`). If empty, the value will be populated
      from `Job.input_uri`.
  """

  key = _messages.StringField(1)
  preprocessingConfig = _messages.MessageField('PreprocessingConfig', 2)
  uri = _messages.StringField(3)


class Job(_messages.Message):
  r"""Transcoding job resource.

  Enums:
    StateValueValuesEnum: Output only. The current state of the job.

  Fields:
    config: The configuration for this job.
    createTime: Output only. The time the job was created.
    endTime: Output only. The time the transcoding finished.
    failureDetails: Output only. List of failure details. This property may
      contain additional information about the failure when `failure_reason`
      is present. *Note*: This feature is not yet available.
    failureReason: Output only. A description of the reason for the failure.
      This property is always present when `state` is `FAILED`.
    inputUri: Input only. Specify the `input_uri` to populate empty `uri`
      fields in each element of `Job.config.inputs` or
      `JobTemplate.config.inputs` when using template. URI of the media. Input
      files must be at least 5 seconds in duration and stored in Cloud Storage
      (for example, `gs://bucket/inputs/file.mp4`).
    name: The resource name of the job. Format:
      `projects/{project}/locations/{location}/jobs/{job}`
    originUri: Output only. The origin URI. *Note*: This feature is not yet
      available.
    outputUri: Input only. Specify the `output_uri` to populate an empty
      `Job.config.output.uri` or `JobTemplate.config.output.uri` when using
      template. URI for the output file(s). For example, `gs://my-
      bucket/outputs/`.
    priority: Specify the priority of the job. Enter a value between 0 and
      100, where 0 is the lowest priority and 100 is the highest priority. The
      default is 0.
    progress: Output only. Estimated fractional progress, from `0` to `1` for
      each step. *Note*: This feature is not yet available.
    startTime: Output only. The time the transcoding started.
    state: Output only. The current state of the job.
    templateId: Input only. Specify the `template_id` to use for populating
      `Job.config`. The default is `preset/web-hd`. Preset Transcoder
      templates: - `preset/{preset_id}` - User defined JobTemplate:
      `{job_template_id}`
    ttlAfterCompletionDays: Job time to live value in days, which will be
      effective after job completion. Job should be deleted automatically
      after the given TTL. Enter a value between 1 and 90. The default is 30.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""Output only. The current state of the job.

    Values:
      PROCESSING_STATE_UNSPECIFIED: The processing state is not specified.
      PENDING: The job is enqueued and will be picked up for processing soon.
      RUNNING: The job is being processed.
      SUCCEEDED: The job has been completed successfully.
      FAILED: The job has failed. For additional information, see
        `failure_reason` and `failure_details`
    """
    PROCESSING_STATE_UNSPECIFIED = 0
    PENDING = 1
    RUNNING = 2
    SUCCEEDED = 3
    FAILED = 4

  config = _messages.MessageField('JobConfig', 1)
  createTime = _messages.StringField(2)
  endTime = _messages.StringField(3)
  failureDetails = _messages.MessageField('FailureDetail', 4, repeated=True)
  failureReason = _messages.StringField(5)
  inputUri = _messages.StringField(6)
  name = _messages.StringField(7)
  originUri = _messages.MessageField('OriginUri', 8)
  outputUri = _messages.StringField(9)
  priority = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  progress = _messages.MessageField('Progress', 11)
  startTime = _messages.StringField(12)
  state = _messages.EnumField('StateValueValuesEnum', 13)
  templateId = _messages.StringField(14)
  ttlAfterCompletionDays = _messages.IntegerField(15, variant=_messages.Variant.INT32)


class JobConfig(_messages.Message):
  r"""Job configuration

  Fields:
    adBreaks: List of ad breaks. Specifies where to insert ad break tags in
      the output manifests.
    editList: List of `Edit atom`s. Defines the ultimate timeline of the
      resulting file or manifest.
    elementaryStreams: List of elementary streams.
    inputs: List of input assets stored in Cloud Storage.
    manifests: List of output manifests.
    muxStreams: List of multiplexing settings for output streams.
    output: Output configuration.
    overlays: List of overlays on the output video, in descending Z-order.
    pubsubDestination: Destination on Pub/Sub.
    spriteSheets: List of output sprite sheets.
  """

  adBreaks = _messages.MessageField('AdBreak', 1, repeated=True)
  editList = _messages.MessageField('EditAtom', 2, repeated=True)
  elementaryStreams = _messages.MessageField('ElementaryStream', 3, repeated=True)
  inputs = _messages.MessageField('Input', 4, repeated=True)
  manifests = _messages.MessageField('Manifest', 5, repeated=True)
  muxStreams = _messages.MessageField('MuxStream', 6, repeated=True)
  output = _messages.MessageField('Output', 7)
  overlays = _messages.MessageField('Overlay', 8, repeated=True)
  pubsubDestination = _messages.MessageField('PubsubDestination', 9)
  spriteSheets = _messages.MessageField('SpriteSheet', 10, repeated=True)


class JobTemplate(_messages.Message):
  r"""Transcoding job template resource.

  Fields:
    config: The configuration for this template.
    name: The resource name of the job template. Format:
      `projects/{project}/locations/{location}/jobTemplates/{job_template}`
  """

  config = _messages.MessageField('JobConfig', 1)
  name = _messages.StringField(2)


class ListJobTemplatesResponse(_messages.Message):
  r"""Response message for `TranscoderService.ListJobTemplates`.

  Fields:
    jobTemplates: List of job templates in the specified region.
    nextPageToken: The pagination token.
  """

  jobTemplates = _messages.MessageField('JobTemplate', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class ListJobsResponse(_messages.Message):
  r"""Response message for `TranscoderService.ListJobs`.

  Fields:
    jobs: List of jobs in the specified region.
    nextPageToken: The pagination token.
  """

  jobs = _messages.MessageField('Job', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class Manifest(_messages.Message):
  r"""Manifest configuration.

  Enums:
    TypeValueValuesEnum: Required. Type of the manifest, can be "HLS" or
      "DASH".

  Fields:
    fileName: The name of the generated file. The default is `"manifest"` with
      the extension suffix corresponding to the `Manifest.type`.
    muxStreams: Required. List of user given `MuxStream.key`s that should
      appear in this manifest. When `Manifest.type` is `HLS`, a media manifest
      with name `MuxStream.key` and `.m3u8` extension is generated for each
      element of the `Manifest.mux_streams`.
    type: Required. Type of the manifest, can be "HLS" or "DASH".
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""Required. Type of the manifest, can be "HLS" or "DASH".

    Values:
      MANIFEST_TYPE_UNSPECIFIED: The manifest type is not specified.
      HLS: Create `"HLS"` manifest. The corresponding file extension is
        `".m3u8"`.
      DASH: Create `"DASH"` manifest. The corresponding file extension is
        `".mpd"`.
    """
    MANIFEST_TYPE_UNSPECIFIED = 0
    HLS = 1
    DASH = 2

  fileName = _messages.StringField(1)
  muxStreams = _messages.StringField(2, repeated=True)
  type = _messages.EnumField('TypeValueValuesEnum', 3)


class MpegCommonEncryption(_messages.Message):
  r"""Configuration for MPEG Common Encryption (MPEG-CENC).

  Fields:
    keyId: Required. 128 bit Key ID represented as lowercase hexadecimal
      digits for use with common encryption.
    scheme: Required. Specify the encryption scheme. Supported encryption
      schemes: - 'cenc' - 'cbcs'
  """

  keyId = _messages.StringField(1)
  scheme = _messages.StringField(2)


class MuxStream(_messages.Message):
  r"""Multiplexing settings for output stream.

  Fields:
    container: The container format. The default is `"mp4"` Supported
      container formats: - 'ts' - 'fmp4'- the corresponding file extension is
      `".m4s"` - 'mp4' - 'vtt'
    elementaryStreams: List of `ElementaryStream.key`s multiplexed in this
      stream.
    encryption: Encryption settings.
    fileName: The name of the generated file. The default is `MuxStream.key`
      with the extension suffix corresponding to the `MuxStream.container`.
      Individual segments also have an incremental 10-digit zero-padded suffix
      starting from 0 before the extension, such as
      `"mux_stream0000000123.ts"`.
    key: A unique key for this multiplexed stream. HLS media manifests will be
      named `MuxStream.key` with the `".m3u8"` extension suffix.
    segmentSettings: Segment settings for `"ts"`, `"fmp4"` and `"vtt"`.
  """

  container = _messages.StringField(1)
  elementaryStreams = _messages.StringField(2, repeated=True)
  encryption = _messages.MessageField('Encryption', 3)
  fileName = _messages.StringField(4)
  key = _messages.StringField(5)
  segmentSettings = _messages.MessageField('SegmentSettings', 6)


class NormalizedCoordinate(_messages.Message):
  r"""2D normalized coordinates. Default: `{0.0, 0.0}`

  Fields:
    x: Normalized x coordinate.
    y: Normalized y coordinate.
  """

  x = _messages.FloatField(1)
  y = _messages.FloatField(2)


class OriginUri(_messages.Message):
  r"""The origin URI.

  Fields:
    dash: Dash manifest URI. If multiple Dash manifests are created, only the
      first one is listed.
    hls: HLS manifest URI per
      https://tools.ietf.org/html/rfc8216#section-4.3.4. If multiple HLS
      manifests are created, only the first one is listed.
  """

  dash = _messages.StringField(1)
  hls = _messages.StringField(2)


class Output(_messages.Message):
  r"""Location of output file(s) in a Cloud Storage bucket.

  Fields:
    uri: URI for the output file(s). For example, `gs://my-bucket/outputs/`.
      If empty the value is populated from `Job.output_uri`.
  """

  uri = _messages.StringField(1)


class Overlay(_messages.Message):
  r"""Overlay configuration.

  Fields:
    animations: List of Animations. The list should be chronological, without
      any time overlap.
    image: Image overlay.
  """

  animations = _messages.MessageField('Animation', 1, repeated=True)
  image = _messages.MessageField('Image', 2)


class Pad(_messages.Message):
  r"""Pad filter configuration for the input video. The padded input video is
  scaled after padding with black to match the output resolution.

  Fields:
    bottomPixels: The number of pixels to add to the bottom. The default is 0.
    leftPixels: The number of pixels to add to the left. The default is 0.
    rightPixels: The number of pixels to add to the right. The default is 0.
    topPixels: The number of pixels to add to the top. The default is 0.
  """

  bottomPixels = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  leftPixels = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  rightPixels = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  topPixels = _messages.IntegerField(4, variant=_messages.Variant.INT32)


class PreprocessingConfig(_messages.Message):
  r"""Preprocessing configurations.

  Fields:
    audio: Audio preprocessing configuration.
    color: Color preprocessing configuration.
    crop: Specify the video cropping configuration.
    deblock: Deblock preprocessing configuration.
    denoise: Denoise preprocessing configuration.
    pad: Specify the video pad filter configuration.
  """

  audio = _messages.MessageField('Audio', 1)
  color = _messages.MessageField('Color', 2)
  crop = _messages.MessageField('Crop', 3)
  deblock = _messages.MessageField('Deblock', 4)
  denoise = _messages.MessageField('Denoise', 5)
  pad = _messages.MessageField('Pad', 6)


class Progress(_messages.Message):
  r"""Estimated fractional progress for each step, from `0` to `1`.

  Fields:
    analyzed: Estimated fractional progress for `analyzing` step.
    encoded: Estimated fractional progress for `encoding` step.
    notified: Estimated fractional progress for `notifying` step.
    uploaded: Estimated fractional progress for `uploading` step.
  """

  analyzed = _messages.FloatField(1)
  encoded = _messages.FloatField(2)
  notified = _messages.FloatField(3)
  uploaded = _messages.FloatField(4)


class PublicKeys(_messages.Message):
  r"""Wraps a keyset binary proto representation.

  Fields:
    keyset: The keyset in binary.
  """

  keyset = _messages.BytesField(1)


class PubsubDestination(_messages.Message):
  r"""A Pub/Sub destination.

  Fields:
    topic: The name of the Pub/Sub topic to publish job completion
      notification to. For example: `projects/{project}/topics/{topic}`.
  """

  topic = _messages.StringField(1)


class SampleAesEncryption(_messages.Message):
  r"""Configuration for SAMPLE-AES encryption.

  Fields:
    keyUri: Required. URI of the key delivery service. This URI is inserted
      into the M3U8 header.
  """

  keyUri = _messages.StringField(1)


class SegmentSettings(_messages.Message):
  r"""Segment settings for `"ts"`, `"fmp4"` and `"vtt"`.

  Fields:
    individualSegments: Required. Create an individual segment file. The
      default is `false`.
    segmentDuration: Duration of the segments in seconds. The default is
      `"6.0s"`. Note that `segmentDuration` must be greater than or equal to
      [`gopDuration`](#videostream), and `segmentDuration` must be divisible
      by [`gopDuration`](#videostream).
  """

  individualSegments = _messages.BooleanField(1)
  segmentDuration = _messages.StringField(2)


class SpriteSheet(_messages.Message):
  r"""Sprite sheet configuration.

  Fields:
    columnCount: The maximum number of sprites per row in a sprite sheet. The
      default is 0, which indicates no maximum limit.
    endTimeOffset: End time in seconds, relative to the output file timeline.
      When `end_time_offset` is not specified, the sprites are generated until
      the end of the output file.
    filePrefix: Required. File name prefix for the generated sprite sheets.
      Each sprite sheet has an incremental 10-digit zero-padded suffix
      starting from 0 before the extension, such as
      `"sprite_sheet0000000123.jpeg"`.
    format: Format type. The default is `"jpeg"`. Supported formats: - 'jpeg'
    interval: Starting from `0s`, create sprites at regular intervals. Specify
      the interval value in seconds.
    quality: The quality of the generated sprite sheet. Enter a value between
      1 and 100, where 1 is the lowest quality and 100 is the highest quality.
      The default is 100. A high quality value corresponds to a low image data
      compression ratio.
    rowCount: The maximum number of rows per sprite sheet. When the sprite
      sheet is full, a new sprite sheet is created. The default is 0, which
      indicates no maximum limit.
    spriteHeightPixels: Required. The height of sprite in pixels. Must be an
      even integer. To preserve the source aspect ratio, set the
      SpriteSheet.sprite_height_pixels field or the
      SpriteSheet.sprite_width_pixels field, but not both (the API will
      automatically calculate the missing field).
    spriteWidthPixels: Required. The width of sprite in pixels. Must be an
      even integer. To preserve the source aspect ratio, set the
      SpriteSheet.sprite_width_pixels field or the
      SpriteSheet.sprite_height_pixels field, but not both (the API will
      automatically calculate the missing field).
    startTimeOffset: Start time in seconds, relative to the output file
      timeline. Determines the first sprite to pick. The default is `0s`.
    totalCount: Total number of sprites. Create the specified number of
      sprites distributed evenly across the timeline of the output media. The
      default is 100.
  """

  columnCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  endTimeOffset = _messages.StringField(2)
  filePrefix = _messages.StringField(3)
  format = _messages.StringField(4)
  interval = _messages.StringField(5)
  quality = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  rowCount = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  spriteHeightPixels = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  spriteWidthPixels = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  startTimeOffset = _messages.StringField(10)
  totalCount = _messages.IntegerField(11, variant=_messages.Variant.INT32)


class StandardQueryParameters(_messages.Message):
  r"""Query parameters accepted by all methods.

  Enums:
    FXgafvValueValuesEnum: V1 error format.
    AltValueValuesEnum: Data format for response.

  Fields:
    f__xgafv: V1 error format.
    access_token: OAuth access token.
    alt: Data format for response.
    callback: JSONP
    fields: Selector specifying which fields to include in a partial response.
    key: API key. Your API key identifies your project and provides you with
      API access, quota, and reports. Required unless you provide an OAuth 2.0
      token.
    oauth_token: OAuth 2.0 token for the current user.
    prettyPrint: Returns response with indentations and line breaks.
    quotaUser: Available to use for quota purposes for server-side
      applications. Can be any arbitrary string assigned to a user, but should
      not exceed 40 characters.
    trace: A tracing token of the form "token:<tokenid>" to include in api
      requests.
    uploadType: Legacy upload protocol for media (e.g. "media", "multipart").
    upload_protocol: Upload protocol for media (e.g. "raw", "multipart").
  """

  class AltValueValuesEnum(_messages.Enum):
    r"""Data format for response.

    Values:
      json: Responses with Content-Type of application/json
      media: Media download with context-dependent Content-Type
      proto: Responses with Content-Type of application/x-protobuf
    """
    json = 0
    media = 1
    proto = 2

  class FXgafvValueValuesEnum(_messages.Enum):
    r"""V1 error format.

    Values:
      _1: v1 error format
      _2: v2 error format
    """
    _1 = 0
    _2 = 1

  f__xgafv = _messages.EnumField('FXgafvValueValuesEnum', 1)
  access_token = _messages.StringField(2)
  alt = _messages.EnumField('AltValueValuesEnum', 3, default='json')
  callback = _messages.StringField(4)
  fields = _messages.StringField(5)
  key = _messages.StringField(6)
  oauth_token = _messages.StringField(7)
  prettyPrint = _messages.BooleanField(8, default=True)
  quotaUser = _messages.StringField(9)
  trace = _messages.StringField(10)
  uploadType = _messages.StringField(11)
  upload_protocol = _messages.StringField(12)


class TextAtom(_messages.Message):
  r"""The mapping for the `Job.edit_list` atoms with text `EditAtom.inputs`.

  Fields:
    inputs: List of `Job.inputs` that should be embedded in this atom. Only
      one input is supported.
    key: Required. The `EditAtom.key` that references atom with text inputs in
      the `Job.edit_list`.
  """

  inputs = _messages.MessageField('TextInput', 1, repeated=True)
  key = _messages.StringField(2)


class TextInput(_messages.Message):
  r"""Identifies which input file and track should be used.

  Fields:
    key: Required. The `Input.key` that identifies the input file.
    track: Required. The zero-based index of the track in the input file.
  """

  key = _messages.StringField(1)
  track = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class TextStream(_messages.Message):
  r"""Encoding of a text stream. For example, closed captions or subtitles.

  Fields:
    codec: The codec for this text stream. The default is `"webvtt"`.
      Supported text codecs: - 'srt' - 'ttml' - 'cea608' - 'cea708' - 'webvtt'
    languageCode: Required. The BCP-47 language code, such as `"en-US"` or
      `"sr-Latn"`. For more information, see
      https://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
    mapping: The mapping for the `Job.edit_list` atoms with text
      `EditAtom.inputs`.
  """

  codec = _messages.StringField(1)
  languageCode = _messages.StringField(2)
  mapping = _messages.MessageField('TextAtom', 3, repeated=True)


class TranscoderGetPublicKeysRequest(_messages.Message):
  r"""A TranscoderGetPublicKeysRequest object."""


class TranscoderProjectsLocationsJobTemplatesCreateRequest(_messages.Message):
  r"""A TranscoderProjectsLocationsJobTemplatesCreateRequest object.

  Fields:
    jobTemplate: A JobTemplate resource to be passed as the request body.
    jobTemplateId: Required. The ID to use for the job template, which will
      become the final component of the job template's resource name. This
      value should be 4-63 characters, and valid characters must match the
      regular expression `a-zA-Z*`.
    parent: Required. The parent location to create this job template. Format:
      `projects/{project}/locations/{location}`
  """

  jobTemplate = _messages.MessageField('JobTemplate', 1)
  jobTemplateId = _messages.StringField(2)
  parent = _messages.StringField(3, required=True)


class TranscoderProjectsLocationsJobTemplatesDeleteRequest(_messages.Message):
  r"""A TranscoderProjectsLocationsJobTemplatesDeleteRequest object.

  Fields:
    name: Required. The name of the job template to delete.
      `projects/{project}/locations/{location}/jobTemplates/{job_template}`
  """

  name = _messages.StringField(1, required=True)


class TranscoderProjectsLocationsJobTemplatesGetRequest(_messages.Message):
  r"""A TranscoderProjectsLocationsJobTemplatesGetRequest object.

  Fields:
    name: Required. The name of the job template to retrieve. Format:
      `projects/{project}/locations/{location}/jobTemplates/{job_template}`
  """

  name = _messages.StringField(1, required=True)


class TranscoderProjectsLocationsJobTemplatesListRequest(_messages.Message):
  r"""A TranscoderProjectsLocationsJobTemplatesListRequest object.

  Fields:
    pageSize: The maximum number of items to return.
    pageToken: The `next_page_token` value returned from a previous List
      request, if any.
    parent: Required. The parent location from which to retrieve the
      collection of job templates. Format:
      `projects/{project}/locations/{location}`
  """

  pageSize = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(2)
  parent = _messages.StringField(3, required=True)


class TranscoderProjectsLocationsJobsCreateRequest(_messages.Message):
  r"""A TranscoderProjectsLocationsJobsCreateRequest object.

  Fields:
    job: A Job resource to be passed as the request body.
    parent: Required. The parent location to create and process this job.
      Format: `projects/{project}/locations/{location}`
  """

  job = _messages.MessageField('Job', 1)
  parent = _messages.StringField(2, required=True)


class TranscoderProjectsLocationsJobsDeleteRequest(_messages.Message):
  r"""A TranscoderProjectsLocationsJobsDeleteRequest object.

  Fields:
    name: Required. The name of the job to delete. Format:
      `projects/{project}/locations/{location}/jobs/{job}`
  """

  name = _messages.StringField(1, required=True)


class TranscoderProjectsLocationsJobsGetRequest(_messages.Message):
  r"""A TranscoderProjectsLocationsJobsGetRequest object.

  Fields:
    name: Required. The name of the job to retrieve. Format:
      `projects/{project}/locations/{location}/jobs/{job}`
  """

  name = _messages.StringField(1, required=True)


class TranscoderProjectsLocationsJobsListRequest(_messages.Message):
  r"""A TranscoderProjectsLocationsJobsListRequest object.

  Fields:
    pageSize: The maximum number of items to return.
    pageToken: The `next_page_token` value returned from a previous List
      request, if any.
    parent: Required. Format: `projects/{project}/locations/{location}`
  """

  pageSize = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(2)
  parent = _messages.StringField(3, required=True)


class VideoStream(_messages.Message):
  r"""Video stream resource.

  Fields:
    allowOpenGop: Specifies whether an open Group of Pictures (GOP) structure
      should be allowed or not. The default is `false`.
    aqStrength: Specify the intensity of the adaptive quantizer (AQ). Must be
      between 0 and 1, where 0 disables the quantizer and 1 maximizes the
      quantizer. A higher value equals a lower bitrate but smoother image. The
      default is 0.
    bFrameCount: The number of consecutive B-frames. Must be greater than or
      equal to zero. Must be less than `VideoStream.gop_frame_count` if set.
      The default is 0.
    bPyramid: Allow B-pyramid for reference frame selection. This may not be
      supported on all decoders. The default is `false`.
    bitrateBps: Required. The video bitrate in bits per second. The minimum
      value is 1,000. The maximum value for H264/H265 is 800,000,000. The
      maximum value for VP9 is 480,000,000.
    codec: Codec type. The following codecs are supported: * `h264` (default)
      * `h265` * `vp9`
    crfLevel: Target CRF level. Must be between 10 and 36, where 10 is the
      highest quality and 36 is the most efficient compression. The default is
      21.
    enableTwoPass: Use two-pass encoding strategy to achieve better video
      quality. `VideoStream.rate_control_mode` must be `"vbr"`. The default is
      `false`.
    entropyCoder: The entropy coder to use. The default is `"cabac"`.
      Supported entropy coders: - 'cavlc' - 'cabac'
    frameRate: Required. The target video frame rate in frames per second
      (FPS). Must be less than or equal to 120. Will default to the input
      frame rate if larger than the input frame rate. The API will generate an
      output FPS that is divisible by the input FPS, and smaller or equal to
      the target FPS. See [Calculate frame
      rate](https://cloud.google.com/transcoder/docs/concepts/frame-rate) for
      more information.
    gopDuration: Select the GOP size based on the specified duration. The
      default is `"3s"`. Note that `gopDuration` must be less than or equal to
      [`segmentDuration`](#SegmentSettings), and
      [`segmentDuration`](#SegmentSettings) must be divisible by
      `gopDuration`.
    gopFrameCount: Select the GOP size based on the specified frame count.
      Must be greater than zero.
    heightPixels: The height of the video in pixels. Must be an even integer.
      When not specified, the height is adjusted to match the specified width
      and input aspect ratio. If both are omitted, the input height is used.
    pixelFormat: Pixel format to use. The default is `"yuv420p"`. Supported
      pixel formats: - 'yuv420p' pixel format. - 'yuv422p' pixel format. -
      'yuv444p' pixel format. - 'yuv420p10' 10-bit HDR pixel format. -
      'yuv422p10' 10-bit HDR pixel format. - 'yuv444p10' 10-bit HDR pixel
      format. - 'yuv420p12' 12-bit HDR pixel format. - 'yuv422p12' 12-bit HDR
      pixel format. - 'yuv444p12' 12-bit HDR pixel format.
    preset: Enforces the specified codec preset. The default is `veryfast`.
      The available options are FFmpeg-compatible. Note that certain values
      for this field may cause the transcoder to override other fields you set
      in the `VideoStream` message.
    profile: Enforces the specified codec profile. The following profiles are
      supported: * `baseline` * `main` * `high` (default) The available
      options are FFmpeg-compatible. Note that certain values for this field
      may cause the transcoder to override other fields you set in the
      `VideoStream` message.
    rateControlMode: Specify the `rate_control_mode`. The default is `"vbr"`.
      Supported rate control modes: - 'vbr' - variable bitrate - 'crf' -
      constant rate factor
    tune: Enforces the specified codec tune. The available options are FFmpeg-
      compatible. Note that certain values for this field may cause the
      transcoder to override other fields you set in the `VideoStream`
      message.
    vbvFullnessBits: Initial fullness of the Video Buffering Verifier (VBV)
      buffer in bits. Must be greater than zero. The default is equal to 90%
      of `VideoStream.vbv_size_bits`.
    vbvSizeBits: Size of the Video Buffering Verifier (VBV) buffer in bits.
      Must be greater than zero. The default is equal to
      `VideoStream.bitrate_bps`.
    widthPixels: The width of the video in pixels. Must be an even integer.
      When not specified, the width is adjusted to match the specified height
      and input aspect ratio. If both are omitted, the input width is used.
  """

  allowOpenGop = _messages.BooleanField(1)
  aqStrength = _messages.FloatField(2)
  bFrameCount = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  bPyramid = _messages.BooleanField(4)
  bitrateBps = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  codec = _messages.StringField(6)
  crfLevel = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  enableTwoPass = _messages.BooleanField(8)
  entropyCoder = _messages.StringField(9)
  frameRate = _messages.FloatField(10)
  gopDuration = _messages.StringField(11)
  gopFrameCount = _messages.IntegerField(12, variant=_messages.Variant.INT32)
  heightPixels = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  pixelFormat = _messages.StringField(14)
  preset = _messages.StringField(15)
  profile = _messages.StringField(16)
  rateControlMode = _messages.StringField(17)
  tune = _messages.StringField(18)
  vbvFullnessBits = _messages.IntegerField(19, variant=_messages.Variant.INT32)
  vbvSizeBits = _messages.IntegerField(20, variant=_messages.Variant.INT32)
  widthPixels = _messages.IntegerField(21, variant=_messages.Variant.INT32)


encoding.AddCustomJsonFieldMapping(
    StandardQueryParameters, 'f__xgafv', '$.xgafv')
encoding.AddCustomJsonEnumMapping(
    StandardQueryParameters.FXgafvValueValuesEnum, '_1', '1')
encoding.AddCustomJsonEnumMapping(
    StandardQueryParameters.FXgafvValueValuesEnum, '_2', '2')



# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Create a backend binding.

Binds a Compute Engine backend service to your KubeRun service.
"""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

import json

from googlecloudsdk.api_lib.kuberun import backendbinding
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.kuberun import flags
from googlecloudsdk.command_lib.kuberun import kuberun_command
from googlecloudsdk.core import exceptions

_DETAILED_HELP = {
    'EXAMPLES':
        """
        To bind a KubeRun service ``SERVICE'' in the default namespace
        to a Compute Engine backend service ``BACKEND_SERVICE'' with a maximum
        requests per second limit ``MAX_RATE'', run:

            $ {command} --service=SERVICE --backend-service=BACKEND_SERVICE --max-rate=MAX_RATE

        To bind a KubeRun service ``SERVICE'' in a specific namespace
        ``NAMESPACE'' to a Compute Engine backend service ``BACKEND_SERVICE''
        with a maximum requests per second limit ``MAX_RATE'', run:

            $ {command} --service=SERVICE --namespace=NAMESPACE --backend-service=BACKEND_SERVICE --max-rate=MAX_RATE
        """,
}


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Create(kuberun_command.KubeRunCommand):
  """Creates a backend binding."""

  detailed_help = _DETAILED_HELP
  flags = [
      flags.NamespaceFlag(),
      flags.ClusterConnectionFlags(),
      flags.MaxRateFlag(True),
  ]

  @classmethod
  def Args(cls, parser):
    super(Create, cls).Args(parser)
    parser.add_argument(
        '--service',
        help='Name of the KubeRun service to bind to a Compute Engine backend service.',
        required=True)
    parser.add_argument(
        '--backend-service',
        help='Name of the Compute Engine backend service to bind to the KubeRun service.',
        required=True)
    parser.display_info.AddFormat("""table(
        name:label=NAME,
        service:label=SERVICE,
        ready:label=READY)""")

  def BuildKubeRunArgs(self, args):
    return [
        '--service', args.service, '--backend-service', args.backend_service,
    ] + super(Create, self).BuildKubeRunArgs(args)

  def Command(self):
    return ['core', 'backend-bindings', 'create']

  def SuccessResult(self, out, args):
    if out:
      return backendbinding.BackendBinding(json.loads(out))
    else:
      raise exceptions.Error(
          'Could not create backend binding [{}] for service [{}]'.format(
              args.domain, args.service))



# -*- coding: utf-8 -*- #
# Copyright 2018 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Create Attestor command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

import textwrap

from googlecloudsdk.api_lib.container.binauthz import apis
from googlecloudsdk.api_lib.container.binauthz import attestors
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.container.binauthz import flags


class Create(base.CreateCommand):
  r"""Create an Attestor.

  ## EXAMPLES

  To create an Attestor with an existing Note `projects/my_proj/notes/my_note`:

    $ {command} \
        my_new_attestor
        --attestation-authority-note=my_note \
        --attestation-authority-note-project=my_proj \
  """

  @classmethod
  def Args(cls, parser):
    flags.AddConcepts(
        parser,
        flags.GetAttestorPresentationSpec(
            positional=True,
            group_help='The attestor to be created.',
        ),
        flags.GetAuthorityNotePresentationSpec(
            base_name='attestation-authority-note',
            required=True,
            positional=False,
            group_help=textwrap.dedent("""\
                The Container Analysis ATTESTATION_AUTHORITY Note to which the
                created attestor will be bound.

                For the attestor to be able to access and use the Note,
                the Note must exist and the active gcloud account (core/account)
                must have the `containeranalysis.notes.listOccurrences` permission
                for the Note. This can be achieved by granting the
                `containeranalysis.notes.occurrences.viewer` role to the active
                account for the Note resource in question.

                """),
        ),
    )
    parser.add_argument(
        '--description', required=False, help='A description for the attestor')

  def Run(self, args):
    attestor_ref = args.CONCEPTS.attestor.Parse()
    note_ref = args.CONCEPTS.attestation_authority_note.Parse()

    api_version = apis.GetApiVersion(self.ReleaseTrack())
    return attestors.Client(api_version).Create(
        attestor_ref, note_ref, description=args.description)



# -*- coding: utf-8 -*- #
# Copyright 2020 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""services peered-dns-domains create command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.cloudresourcemanager import projects_api
from googlecloudsdk.api_lib.services import peering
from googlecloudsdk.api_lib.services import services_util
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.projects import util as projects_util
from googlecloudsdk.core import log
from googlecloudsdk.core import properties

_OP_BASE_CMD = 'gcloud services vpc-peerings operations '
_OP_WAIT_CMD = _OP_BASE_CMD + 'wait {0}'


@base.ReleaseTracks(
    base.ReleaseTrack.ALPHA,
    base.ReleaseTrack.BETA,
    base.ReleaseTrack.GA,
)
class Create(base.SilentCommand):
  """Create a peered DNS domain for a private service connection."""

  detailed_help = {
      'DESCRIPTION':
          """\
          This command creates a peered DNS domain for a private service
          connection which sends requests for records in a given namespace
          originating in the service producer VPC network to the consumer
          VPC network to be resolved.
          """,
      'EXAMPLES':
          """\
          To create a peered DNS domain called `example-com` which forwards DNS
          requests for the domain suffix `example.com.` for a private service
          connection between service `peering-service` and the consumer network
          `my-network` in the current project, run:

            $ {command} example-com --network=my-network \\
                --service=peering-service --dns-suffix=example.com.

          To run the same command asynchronously (non-blocking), run:

            $ {command} example-com --network=my-network \\
                --service=peering-service --dns-suffix=example.com. \\
                --async
          """,
  }

  @staticmethod
  def Args(parser):
    """Args is called by calliope to gather arguments for this command.

    Args:
      parser: An argparse parser that you can use to add arguments that go on
        the command line after this command. Positional arguments are allowed.
    """
    parser.add_argument(
        'name', help='The name of the peered DNS domain to create.')
    parser.add_argument(
        '--network',
        metavar='NETWORK',
        required=True,
        help='The network in the consumer project peered with the service.')
    parser.add_argument(
        '--service',
        metavar='SERVICE',
        default='servicenetworking.googleapis.com',
        help='The name of the service to create a peered DNS domain for.')
    parser.add_argument(
        '--dns-suffix',
        metavar='DNS_SUFFIX',
        required=True,
        help='The DNS domain name suffix of the peered DNS domain.')
    base.ASYNC_FLAG.AddToParser(parser)

  def Run(self, args):
    """Run 'services peered-dns-domains create'.

    Args:
      args: argparse.Namespace, The arguments that this command was invoked
        with.
    """
    project = properties.VALUES.core.project.Get(required=True)
    project_number = _GetProjectNumber(project)
    op = peering.CreatePeeredDnsDomain(
        project_number,
        args.service,
        args.network,
        args.name,
        args.dns_suffix,
    )
    if args.async_:
      cmd = _OP_WAIT_CMD.format(op.name)
      log.status.Print('Asynchronous operation is in progress... '
                       'Use the following command to wait for its '
                       'completion:\n {0}'.format(cmd))
      return
    op = services_util.WaitOperation(op.name, peering.GetOperation)
    services_util.PrintOperation(op)


def _GetProjectNumber(project_id):
  return projects_api.Get(projects_util.ParseProject(project_id)).projectNumber
